@@ -5,7 +5,7 @@ use Carp;
 use JSON;
 use Search::Tools::XML;
 
-our $VERSION = '0.001008';
+our $VERSION = '0.002000';
 
 sub new {
     my $class       = shift;
@@ -20,7 +20,9 @@ sub new {
     my $rollback_path = delete $args{rollback_path}
         or croak "rollback_path required";
     my $config = delete $args{config} or croak "config required";
-    my $version = delete $args{version} || $VERSION;
+    my $version    = delete $args{version} || $VERSION;
+    my $admin_path = delete $args{admin_path};
+    my $ui_path    = delete $args{ui_path};
 
     if ( $req->path ne '/' ) {
         my $resp = 'Resource not found';
@@ -150,11 +152,11 @@ sub new {
     };
     if ( $config->{ui_class} ) {
         $about->{ui_class} = $config->{ui_class};
-        $about->{ui}       = $uri . '/ui';
+        $about->{ui}       = $uri . $ui_path;
     }
     if ( $config->{admin_class} ) {
         $about->{admin_class} = $config->{admin_class};
-        $about->{admin}       = $uri . '/admin';
+        $about->{admin}       = $uri . $admin_path;
     }
     my $resp
         = $format eq 'json'
@@ -219,13 +221,21 @@ automatically be notified of progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Dezi
+    perldoc Dezi::About
 
 
 You can also look for information at:
 
 =over 4
 
+=item * Website
+
+L<http://dezi.org/>
+
+=item * IRC
+
+#dezisearch at freenode
+
 =item * Mailing list
 
 L<https://groups.google.com/forum/#!forum/dezi-search>
